@@ -1,6 +1,6 @@
 test_that("Test cache online", {
   # Get current cache dir
-  current <- esp_hlp_detect_cache_dir()
+  current <- esp_detect_cache_dir()
 
   cat("User cache dir is ", current, "\n")
 
@@ -11,6 +11,8 @@ test_that("Test cache online", {
     verbose = FALSE
   ))
 
+  expect_identical(esp_detect_cache_dir(), testdir)
+
   # Clean
   expect_silent(esp_clear_cache(config = FALSE, verbose = FALSE))
   # Cache dir should be deleted now
